@@ -2,10 +2,10 @@
 # Usage:	plot.walk.MH(walk.mat)
 
 
-plot <- function(walk.mat)
-UseMethod("plot")
-plot.walk.MH <- function(walk.mat)  {
-    plot(walk.mat[1,1],walk.mat[1,2],type="n",
+mhplot <- function(walk.mat)
+UseMethod("mhplot")
+mhplot.walk.MH <- function(walk.mat)  {
+    mhplot(walk.mat[1,1],walk.mat[1,2],type="n",
         xlim=round(range(walk.mat[,1])*1.2),
         ylim=round(range(walk.mat[,2])*1.2),
 	xlab="",ylab="")
